==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ast.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "You created the circle {circle}" : "Creesti'l círculu {circle}",
    "{author} created the circle {circle}" : "{author} creó'l círculu {circle}",
    "You deleted {circle}" : "Desniciesti {circle}",
    "{author} deleted {circle}" : "{author} desanició {circle}",
    "You sent a request to link {circle} with {remote}" : "Unviesti una solicitú pa enllazar {circle} con {remote}",
    "You joined {circle}" : "Xuniestite a {circle}",
    "{member} joined {circle}" : "{member} xunióse a {circle}",
    "You accepted the invitation to join {circle}" : "Aceutesti la invitación pa xunite a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceutó la invitación pa xunise a {circle}",
    "You added {member} as member to {circle}" : "Amestesti a {member} como miembru de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} amestóte como miembru de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} amestó a {member} en {circle}",
    "You accepted {member}'s request to join {circle}" : "Aceutesti la solicitú de {member} pa xunite a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} aceutó la to solicitú pa xunise a {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} aceutó la solicitú de {member} pa xunise a {circle}",
    "You cancelled your request to join {circle}" : "Encaboxesti la to solicitú de xunión a {circle}",
    "You removed {member} from {circle}" : "Desaniciesti a {member} de {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} encaboxó la to invitación pa xunite a {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} encaboxó la invitación de {member} pa xunise a {circle}",
    "You are the new owner of {circle}" : "Yes el dueñu nuevu de {circle}",
    "{member} is the new owner of {circle}" : "{member} ye'l miembru nuevu de {circle}",
    "Personal" : "Personal",
    "Contact" : "Contautu",
    "Circle" : "Círculu",
    "Member" : "Miembru",
    "Moderator" : "Llendador",
    "Admin" : "Almin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s compartió «%s» contigo.",
    "%s on %s" : "%s en %s",
    "Password to access »%s«" : "Contraseña p'acceder a »%s«",
    "Click the button below to open it." : "Primi'l botón d'embaxo p'abrilu.",
    "Open »%s«" : "Abrir «%s»",
    "Circle not found" : "Nun s'alcontró'l círculu",
    "A circle with that name exists" : "Yá esiste un círculu con esti nome",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Nun pue usar l'aplicación Círculos hasta que'l to alministrador permita polo menos una triba de círculu",
    "This member does not exist" : "Esti miembru nun esiste",
    "This user is already a member of the circle" : "Esti usuariu yá ye miembru del círculu",
    "Federated link not found" : "Nun s'alcontró l'enllaz federáu",
    "This feature is not available for personal circles" : "Esta carauterística nun ta disponible pa círculos personales",
    "You cannot join this circle" : "Nun pues xunite a esti círculu",
    "This member is not a moderator" : "Esti miembru nun ye un llendador",
    "This member is the owner of the circle" : "Esti miembru ye'l dueñu'l círculu",
    "You are already a member of this circle" : "Yá yes miembru d'esti círculu",
    "The user is already a member of this circle" : "L'usuariu yá ye miembru d'esti círculu",
    "Accept" : "Aceutar",
    "You need a specify a type of circle" : "Precises especificar una triba de círculu",
    "This member is not the owner of the circle" : "Esti miembru nun ye'l dueñu'l círculu",
    "Could not find share" : "Nun pudo alcontrase la compartición",
    "No files in here" : "Equí nun hai ficheos",
    "No entries found in this folder" : "Nun s'alcontraron entraes nesta carpeta",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificóse'l",
    "Are you sure you want to transfer your ownership?" : "¿De xuru que quies tresmitir la to propiedá?",
    "This action is irreversible" : "Esta aición ye irreversible",
    "Personal circle" : "Círculu personal",
    "Secret circle" : "Círculu secretu",
    "Closed circle" : "Círculu zarráu",
    "Public circle" : "Círculu públicu",
    "Link down" : "Enllaz cayíu",
    "Personal Circle" : "Círculu personal",
    "Secret Circle" : "Círculu secretu",
    "Closed Circle" : "Círculu zarráu",
    "Public Circle" : "Cículu públicu",
    "Secret" : "Secretu",
    "Not a member" : "Nun ye un miembru",
    "Unknown" : "Desconozse",
    "This operation will add/invite all members of the group to the circle" : "Esta operación amestará/convidará a tolos miembros delgrupu al círculu",
    "Are you sure you want to leave this circle?" : "¿De xuru que quies dexar esti círculu?",
    "Are you sure you want to delete this circle?" : "¿De xuru que quies desaniciar esti círculu?",
    "Mail Address" : "Direición de corréu",
    "Accept the request" : "Aceutar la solicitú",
    "Cannot join this circle" : "Nun pues xunite a esti círculu",
    "no error message" : "ensin mensaxe de fallu",
    "You have joined this circle" : "Xuniestite a esti círculu",
    "You have requested to join this circle" : "Solicitesti xunite a esti círculu",
    "Cannot leave this circle" : "Nun se pue dexar esti círculu",
    "Cannot delete this circle" : "Nun pue desaniciase esti círculu",
    "Issue while retrieving the details of this circle" : "Problemes entrín se recibíen los detalles d'esti circulu",
    "A link to <b>{remote}</b> has been requested." : "Solicitóse un enllaz a <b>{remote}</b>.",
    "Local User" : "Usuariu llocal",
    "Local Group" : "Grupu llocal",
    "%s shared »%s« with '%s'." : "%s compartió «%s» con «%s».",
    "The name of your circle must contain at least 3 characters" : "El nome'l to círculu ha contener polo menos 3 caráuteres",
    "Federated circles are not allowed on this Nextcloud" : "Los círculos federaos nun tán permitíos nesti Nextcloud",
    "You cannot create this type of circle" : "Nun pues crear esta triba de círculu",
    "You cannot display this type of circle" : "Nun pues amosar esta triba de círculu",
    "Federated link does not have a valid format" : "L'enllaz federáunun paez tener un formatu válidu",
    "Federated circles are not allowed on the remote Nextcloud" : "Los círculos federaos nun tán permitíos nel Nextcloud remotu",
    "This link exists already" : "Yá esiste esti enllaz",
    "The remote host is down or the Circles app is not installed on it" : "L'agospiu remotu ta cayíu o nun tien instalada l'aplicación Círculos",
    "All circles" : "Tolos círculos",
    "Search circles" : "Guetar círculos",
    "Circles you belong to" : "Círculos nos que tas",
    "Settings" : "Settings",
    "Username" : "Nome d'usuariu",
    "Status" : "Estáu",
    "Link" : "Link",
    "Description" : "Descripción",
    "Change password" : "Camudar contraseña"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ast.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "You created the circle {circle}" : "Creesti'l círculu {circle}",
    "{author} created the circle {circle}" : "{author} creó'l círculu {circle}",
    "You deleted {circle}" : "Desniciesti {circle}",
    "{author} deleted {circle}" : "{author} desanició {circle}",
    "You sent a request to link {circle} with {remote}" : "Unviesti una solicitú pa enllazar {circle} con {remote}",
    "You joined {circle}" : "Xuniestite a {circle}",
    "{member} joined {circle}" : "{member} xunióse a {circle}",
    "You accepted the invitation to join {circle}" : "Aceutesti la invitación pa xunite a {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} aceutó la invitación pa xunise a {circle}",
    "You added {member} as member to {circle}" : "Amestesti a {member} como miembru de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} amestóte como miembru de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} amestó a {member} en {circle}",
    "You accepted {member}'s request to join {circle}" : "Aceutesti la solicitú de {member} pa xunite a {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} aceutó la to solicitú pa xunise a {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} aceutó la solicitú de {member} pa xunise a {circle}",
    "You cancelled your request to join {circle}" : "Encaboxesti la to solicitú de xunión a {circle}",
    "You removed {member} from {circle}" : "Desaniciesti a {member} de {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} encaboxó la to invitación pa xunite a {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} encaboxó la invitación de {member} pa xunise a {circle}",
    "You are the new owner of {circle}" : "Yes el dueñu nuevu de {circle}",
    "{member} is the new owner of {circle}" : "{member} ye'l miembru nuevu de {circle}",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Hidden" : "Anubríu",
    "Local" : "Llocal",
    "Root" : "Raíz",
    "Federated" : "Federated",
    "Contact" : "Contautu",
    "Circle" : "Círculu",
    "Member" : "Miembru",
    "Moderator" : "Llendador",
    "Admin" : "Almin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s compartió «%s» contigo.",
    "%s on %s" : "%s en %s",
    "Password to access »%s«" : "Contraseña p'acceder a »%s«",
    "Click the button below to open it." : "Primi'l botón d'embaxo p'abrilu.",
    "Open »%s«" : "Abrir «%s»",
    "Circle not found" : "Nun s'alcontró'l círculu",
    "A circle with that name exists" : "Yá esiste un círculu con esti nome",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Nun pue usar l'aplicación Círculos hasta que'l to alministrador permita polo menos una triba de círculu",
    "This member does not exist" : "Esti miembru nun esiste",
    "This user is already a member of the circle" : "Esti usuariu yá ye miembru del círculu",
    "Federated link not found" : "Nun s'alcontró l'enllaz federáu",
    "This feature is not available for personal circles" : "Esta carauterística nun ta disponible pa círculos personales",
    "You cannot join this circle" : "Nun pues xunite a esti círculu",
    "This member is not a moderator" : "Esti miembru nun ye un llendador",
    "This member is the owner of the circle" : "Esti miembru ye'l dueñu'l círculu",
    "You are already a member of this circle" : "Yá yes miembru d'esti círculu",
    "The user is already a member of this circle" : "L'usuariu yá ye miembru d'esti círculu",
    "Accept" : "Aceutar",
    "%s" : "%s",
    "Personal Circle" : "Círculu personal",
    "You need a specify a type of circle" : "Precises especificar una triba de círculu",
    "This member is not the owner of the circle" : "Esti miembru nun ye'l dueñu'l círculu",
    "Could not find share" : "Nun pudo alcontrase la compartición",
    "No files in here" : "Equí nun hai ficheos",
    "No entries found in this folder" : "Nun s'alcontraron entraes nesta carpeta",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificóse'l"
},
"nplurals=2; plural=(n != 1);");
